==> bacula-docs-5.0.0.tar.bz2: bacula-docs-5.0.0/home-page/en/pages/documentation.php <==
<? require_once("inc/header.php"); ?>
<table>

   <tr>
     <td class="contentTopic">
     Manuals for Version 5.0.x
     </td>
   </tr>
   <tr>
     <td class="content">
      <ul>
      <li> News about Bacula 
          <a href="<? echo $spath ?>/?page=news"> HTML</a>
         </li>
      <li>New Features in Development Version
         <a href="/5.0.x-manuals/en/main/main/New_Features_in_5_0_0.html"> HTML</a>
         </li><br>
      <li>Bacula Main Reference Guide
         <a href="/5.0.x-manuals/en/main/main.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/main/main/index.html">/HTML </a>
         </li>
      <li>Console and Operators Guide
         <a href="/5.0.x-manuals/en/console/console.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/console/console/index.html">/HTML </a>
         </li>
      <li>Problem Resolution Guide
         <a href="/5.0.x-manuals/en/problems/problems.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/problems/problems/index.html">/HTML </a>
         </li>
      <li>Utility Programs
         <a href="/5.0.x-manuals/en/utility/utility.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/utility/utility/index.html">/HTML </a>
         </li>
      <li>Developers' Guide
         <a href="/5.0.x-manuals/en/developers/developers.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/developers/developers/Developer_s_Guide.html">/HTML </a>
         </li>
      <li>Miscellaneous Guide
         <a href="/5.0.x-manuals/en/misc/misc.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/misc/misc/index.html">/HTML </a>
         </li>
      <br>
      <li> Free Software Foundation Europe FLA
         <a href="FLA-bacula.en.pdf">PDF</a>
       -- (Developer's Fiduciary License Agreement)</li>
      </ul>
     </td>
   </tr>


   <tr>
     <td class="contentTopic">
     Manuals for Previous Version 3.0.x
     </td>
   </tr>
   <tr>
     <td class="content">
      <ul>
      <li> News about Bacula 
          <a href="<? echo $spath ?>/?page=news"> HTML</a>
         </li>
      <li>New Features in current version
         <a href="/3.0.x-manuals/en/concepts/concepts/New_Features_in_Released.html"> HTML</a>
         </li><br>
      <li>Concepts and Overview Guide
         <a href="/3.0.x-manuals/en/concepts/concepts.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/concepts/concepts/Bacula_Concepts_Overview_Gu.html">/HTML </a>
         </li>
      <li>Installation and Configuration Guide
         <a href="/3.0.x-manuals/en/install/install.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/install/install/Bacula_Installation_Configu.html">/HTML </a>
         </li>
      <li>Console and Operators Guide
         <a href="/3.0.x-manuals/en/console/console.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/console/console/Bacula_Console_Operators_Gu.html">/HTML </a>
         </li>
      <li>Problem Resolution Guide
         <a href="/3.0.x-manuals/en/problems/problems.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/problems/problems/Bacula_Problem_Resolution_G.html">/HTML </a>
         </li>
      <li>Catalog Database Guide
         <a href="/3.0.x-manuals/en/catalog/catalog.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/catalog/catalog/Bacula_Catalog_Database_Gui.html">/HTML </a>
      </li>
      <li>Utility Programs
         <a href="/3.0.x-manuals/en/utility/utility.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/utility/utility/Bacula_Utility_Programs.html">/HTML </a>
      </li>
      <li>Developers' Guide
         <a href="/3.0.x-manuals/en/developers/developers.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/developers/developers/Developer_s_Guide.html">/HTML </a>
      </li><br>
      <li> Free Software Foundation Europe FLA
         <a href="FLA-bacula.en.pdf">PDF</a>
       -- (Developer's Fiduciary License Agreement)</li>
      </ul>
     </td>
   </tr>


  <tr>
   <td class="contentTopic">
   Bacula Documentation for Prior Version 2.4.x
   </td>
   </tr>
   
  <tr>
   <td class="content">
   <ul>
   <li> User's Manual 
       <a href="rel-bacula.pdf"> PDF</a>
       <a href="rel-manual/index.html">/HTML</a>
         -- (Version 2.4.4 of the User's Manual)</li>
   <br>
   <li> Tutorial 
      <a href="dev-manual/Brief_Tutorial.html"> HTML</a>
         -- (start here after installing Bacula)</li>
    <li>Bacula-web Guide
      <a href="/manuals/bacula-web/index.html"> HTML</a>
       -- (Guide for the Bacula-web GUI application)</li>
    <li> Developer's Guide 
      <a href="developers.pdf"> PDF</a>
      <a href="developers/index.html">/HTML</a>
        -- (Guide for Bacula developers)</li>
      </ul>
     </td>
   </tr>



</table>
 <p>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-5.2.2.tar.bz2: bacula-docs-5.2.2/home-page/en/pages/documentation.php <==
<? require_once("inc/header.php"); ?>
<table>


   <tr>
     <td class="contentTopic">
     Manuals for Released Version 5.2.x
     </td>
   </tr>
   <tr>
     <td class="content">
      <ul>
      <li> News about Bacula 
          <a href="<? echo $spath ?>/?page=news"> HTML</a>
         </li>
      <li>New Features in Released Version 5.2.x
         <a href="/5.2.x-manuals/en/main/main/New_Features_in_5_2_x.html"> HTML</a>
         </li><br>
      <li>Bacula Main Reference Guide
         <a href="/5.2.x-manuals/en/main/main.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/main/main/index.html">/HTML </a>
         </li>
      <li>Console and Operators Guide
         <a href="/5.2.x-manuals/en/console/console.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/console/console/index.html">/HTML </a>
         </li>
      <li>Problem Resolution Guide
         <a href="/5.2.x-manuals/en/problems/problems.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/problems/problems/index.html">/HTML </a>
         </li>
      <li>Utility Programs
         <a href="/5.2.x-manuals/en/utility/utility.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/utility/utility/index.html">/HTML </a>
         </li>
      <li>Miscellaneous Guide
         <a href="/5.2.x-manuals/en/misc/misc.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/misc/misc/index.html">/HTML </a>
         </li>
      <li>Developers' Guide
         <a href="/5.2.x-manuals/en/developers/developers.pdf"> PDF</a>
         <a href="/5.2.x-manuals/en/developers/developers/Developer_s_Guide.html">/HTML </a>
         </li>
      <br>
     </td>
   </tr>


   <tr>
     <td class="contentTopic">
     Manuals for Previous Released Version 5.0.x
     </td>
   </tr>
   <tr>
     <td class="content">
      <ul>
      <li> News about Bacula 
          <a href="<? echo $spath ?>/?page=news"> HTML</a>
         </li>
      <li>New Features in Version 5.0.x
         <a href="/5.0.x-manuals/en/main/main/New_Features_in_5_0_1.html"> HTML</a>
         </li><br>
      <li>Bacula Main Reference Guide
         <a href="/5.0.x-manuals/en/main/main.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/main/main/index.html">/HTML </a>
         </li>
      <li>Console and Operators Guide
         <a href="/5.0.x-manuals/en/console/console.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/console/console/index.html">/HTML </a>
         </li>
      <li>Problem Resolution Guide
         <a href="/5.0.x-manuals/en/problems/problems.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/problems/problems/index.html">/HTML </a>
         </li>
      <li>Utility Programs
         <a href="/5.0.x-manuals/en/utility/utility.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/utility/utility/index.html">/HTML </a>
         </li>
      <li>Miscellaneous Guide
         <a href="/5.0.x-manuals/en/misc/misc.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/misc/misc/index.html">/HTML </a>
         </li>
      <li>Developers' Guide
         <a href="/5.0.x-manuals/en/developers/developers.pdf"> PDF</a>
         <a href="/5.0.x-manuals/en/developers/developers/Developer_s_Guide.html">/HTML </a>
         </li>
      <li>Bacula-web
         <a href="http://bacula-web.dflc.ch">Bacula-web GUI project site (NEW)</a>
        </li>
      <br />
      <li> Free Software Foundation Europe FLA
         <a href="FLA-bacula.en.pdf">PDF</a>
       -- (Developer's Fiduciary License Agreement)</li>
      </ul>
     </td>
   </tr>


   <tr>
     <td class="contentTopic">
     Manuals for Version 3.0.x  (Unsupported)
     </td>
   </tr>
   <tr>
     <td class="content">
      <ul>
      <li> News about Bacula 
          <a href="<? echo $spath ?>/?page=news"> HTML</a>
         </li>
      <li>New Features in current version
         <a href="/3.0.x-manuals/en/concepts/concepts/New_Features_in_Released.html"> HTML</a>
         </li><br>
      <li>Concepts and Overview Guide
         <a href="/3.0.x-manuals/en/concepts/concepts.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/concepts/concepts/Bacula_Concepts_Overview_Gu.html">/HTML </a>
         </li>
      <li>Installation and Configuration Guide
         <a href="/3.0.x-manuals/en/install/install.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/install/install/Bacula_Installation_Configu.html">/HTML </a>
         </li>
      <li>Console and Operators Guide
         <a href="/3.0.x-manuals/en/console/console.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/console/console/Bacula_Console_Operators_Gu.html">/HTML </a>
         </li>
      <li>Problem Resolution Guide
         <a href="/3.0.x-manuals/en/problems/problems.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/problems/problems/Bacula_Problem_Resolution_G.html">/HTML </a>
         </li>
      <li>Catalog Database Guide
         <a href="/3.0.x-manuals/en/catalog/catalog.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/catalog/catalog/Bacula_Catalog_Database_Gui.html">/HTML </a>
      </li>
      <li>Utility Programs
         <a href="/3.0.x-manuals/en/utility/utility.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/utility/utility/Bacula_Utility_Programs.html">/HTML </a>
      </li>
      <li>Developers' Guide
         <a href="/3.0.x-manuals/en/developers/developers.pdf"> PDF</a>
         <a href="/3.0.x-manuals/en/developers/developers/Developer_s_Guide.html">/HTML </a>
      </li><br>
     </td>
   </tr>


  <tr>
   <td class="contentTopic">
   Bacula Documentation for Prior Version 2.4.x
   </td>
   </tr>
   
  <tr>
   <td class="content">
   <ul>
   <li> User's Manual 
       <a href="/2.4.x-manuals/en/main/rel-bacula.pdf"> PDF</a>
       <a href="/2.4.x-manuals/en/main/index.html">/HTML</a>
         -- (Version 2.4.4 of the User's Manual)</li>
   <br>
   <li> Tutorial 
      <a href="/2.4.x-manuals/en/main/Brief_Tutorial.html"> HTML</a>
         -- (start here after installing Bacula)</li>
    <li>Bacula-web Guide (old version)
      <a href="/2.4.x-manuals/bacula-web/index.html"> HTML</a>
       -- (Guide for the Bacula-web GUI application)</li>
    <li> Developer's Guide 
      <a href="/2.4.x-manuals/en/developers/developers.pdf"> PDF</a>
      <a href="/2.4.x-manuals/en/developers/index.html">/HTML</a>
        -- (Guide for Bacula developers)</li>
      </ul>
     </td>
   </tr>



</table>
 <p>
<? require_once("inc/footer.php"); ?>
